WYMeditor.STRINGS['nl'] = {
    Strong:           'Sterk benadrukken',
    Emphasis:         'Benadrukken',
    Superscript:      'Bovenschrift',
    Subscript:        'Onderschrift',
    Ordered_List:     'Geordende lijst',
    Unordered_List:   'Ongeordende lijst',
    Indent:           'Inspringen',
    Outdent:          'Terugspringen',
    Undo:             'Ongedaan maken',
    Redo:             'Opnieuw uitvoeren',
    Link:             'Linken',
    Unlink:           'Ontlinken',
    Image:            'Afbeelding',
    Table:            'Tabel',
    HTML:             'HTML',
    Paragraph:        'Paragraaf',
    Heading_1:        'Kop 1',
    Heading_2:        'Kop 2',
    Heading_3:        'Kop 3',
    Heading_4:        'Kop 4',
    Heading_5:        'Kop 5',
    Heading_6:        'Kop 6',
    Preformatted:     'Voorgeformatteerd',
    Blockquote:       'Citaat',
    Table_Header:     'Tabel-kop',
    URL:              'URL',
    Title:            'Titel',
    Alternative_Text: 'Alternatieve tekst',
    Caption:          'Bijschrift',
    Summary:          'Summary',
    Number_Of_Rows:   'Aantal rijen',
    Number_Of_Cols:   'Aantal kolommen',
    Submit:           'Versturen',
    Cancel:           'Annuleren',
    Choose:           'Kiezen',
    Preview:          'Voorbeeld bekijken',
    Paste_From_Word:  'Plakken uit Word',
    Tools:            'Hulpmiddelen',
    Containers:       'Teksttypes',
    Classes:          'Klassen',
    Status:           'Status',
    Source_Code:      'Broncode'
};

