WYMeditor.STRINGS['cs'] = {
    Strong:           'Tučné',
    Emphasis:         'Kurzíva',
    Superscript:      'Horní index',
    Subscript:        'Dolní index',
    Ordered_List:     'Číslovaný seznam',
    Unordered_List:   'Nečíslovaný seznam',
    Indent:           'Zvětšit odsazení',
    Outdent:          'Zmenšit odsazení',
    Undo:             'Zpět',
    Redo:             'Znovu',
    Link:             'Vytvořit odkaz',
    Unlink:           'Zrušit odkaz',
    Image:            'Obrázek',
    Table:            'Tabulka',
    HTML:             'HTML',
    Paragraph:        'Odstavec',
    Heading_1:        'Nadpis 1. úrovně',
    Heading_2:        'Nadpis 2. úrovně',
    Heading_3:        'Nadpis 3. úrovně',
    Heading_4:        'Nadpis 4. úrovně',
    Heading_5:        'Nadpis 5. úrovně',
    Heading_6:        'Nadpis 6. úrovně',
    Preformatted:     'Předformátovaný text',
    Blockquote:       'Citace',
    Table_Header:     'Hlavičková buňka tabulky',
    URL:              'Adresa',
    Title:            'Text po najetí myší',
    Alternative_Text: 'Text pro případ nezobrazení obrázku',
    Caption:          'Titulek tabulky',
    Summary:          'Shrnutí obsahu',
    Number_Of_Rows:   'Počet řádek',
    Number_Of_Cols:   'Počet sloupců',
    Submit:           'Vytvořit',
    Cancel:           'Zrušit',
    Choose:           'Vybrat',
    Preview:          'Náhled',
    Paste_From_Word:  'Vložit z Wordu',
    Tools:            'Nástroje',
    Containers:       'Typy obsahu',
    Classes:          'Třídy',
    Status:           'Stav',
    Source_Code:      'Zdrojový kód'
};

