WYMeditor.STRINGS['tr'] = {
    Strong:           'Kalın',
    Emphasis:         'Vurgu',
    Superscript:      'Superscript',
    Subscript:        'Subscript',
    Ordered_List:     'Sıralı List',
    Unordered_List:   'Sırasız List',
    Indent:           'İçerlek',
    Outdent:          'Çıkıntılı',
    Undo:             'Geri Al',
    Redo:             'Yinele',
    Link:             'Bağlantı',
    Unlink:           'Bağlantıyı Kaldır',
    Image:            'İmaj',
    Table:            'Tablo',
    HTML:             'HTML',
    Paragraph:        'Parağraf',
    Heading_1:        'Başlık 1',
    Heading_2:        'Başlık 2',
    Heading_3:        'Başlık 3',
    Heading_4:        'Başlık 4',
    Heading_5:        'Başlık 5',
    Heading_6:        'Başlık 6',
    Preformatted:     'Önceden Formatlı',
    Blockquote:       'Alıntı',
    Table_Header:     'Tablo Başlığı',
    URL:              'URL',
    Title:            'Başlık',
    Alternative_Text: 'Alternatif Metin',
    Caption:          'Etiket',
    Summary:          'Summary',
    Number_Of_Rows:   'Satır sayısı',
    Number_Of_Cols:   'Sütun sayısı',
    Submit:           'Gönder',
    Cancel:           'İptal',
    Choose:           'Seç',
    Preview:          'Önizleme',
    Paste_From_Word:  'Wordden yapıştır',
    Tools:            'Araçlar',
    Containers:       'Kapsayıcılar',
    Classes:          'Sınıflar',
    Status:           'Durum',
    Source_Code:      'Kaynak Kodu'
};

