WYMeditor.STRINGS['pl'] = {
    Strong:           'Nacisk',
    Emphasis:         'Emfaza',
    Superscript:      'Indeks górny',
    Subscript:        'Indeks dolny',
    Ordered_List:     'Lista numerowana',
    Unordered_List:   'Lista wypunktowana',
    Indent:           'Zwiększ wcięcie',
    Outdent:          'Zmniejsz wcięcie',
    Undo:             'Cofnij',
    Redo:             'Ponów',
    Link:             'Wstaw link',
    Unlink:           'Usuń link',
    Image:            'Obraz',
    Table:            'Tabela',
    HTML:             'Źródło HTML',
    Paragraph:        'Akapit',
    Heading_1:        'Nagłówek 1',
    Heading_2:        'Nagłówek 2',
    Heading_3:        'Nagłówek 3',
    Heading_4:        'Nagłówek 4',
    Heading_5:        'Nagłówek 5',
    Heading_6:        'Nagłówek 6',
    Preformatted:     'Preformatowany',
    Blockquote:       'Cytat blokowy',
    Table_Header:     'Nagłówek tabeli',
    URL:              'URL',
    Title:            'Tytuł',
    Alternative_Text: 'Tekst alternatywny',
    Caption:          'Tytuł tabeli',
    Summary:          'Summary',
    Number_Of_Rows:   'Liczba wierszy',
    Number_Of_Cols:   'Liczba kolumn',
    Submit:           'Wyślij',
    Cancel:           'Anuluj',
    Choose:           'Wybierz',
    Preview:          'Podgląd',
    Paste_From_Word:  'Wklej z Worda',
    Tools:            'Narzędzia',
    Containers:       'Format',
    Classes:          'Styl',
    Status:           'Status',
    Source_Code:      'Kod źródłowy'
};

